@@ -416,6 +416,7 @@ padded to 20 field width
 const char *PR_GlobalString (int ofs)
 {
 	static char	line[512];
+	static const int lastchari = Q_COUNTOF(line) - 2;
 	const char	*s;
 	int		i;
 	ddef_t		*def;
@@ -434,7 +435,11 @@ const char *PR_GlobalString (int ofs)
 	i = strlen(line);
 	for ( ; i < 20; i++)
 		strcat (line, " ");
-	strcat (line, " ");
+
+	if (i < lastchari)
+		strcat (line, " ");
+	else
+		line[lastchari] = ' ';
 
 	return line;
 }
@@ -442,6 +447,7 @@ const char *PR_GlobalString (int ofs)
 const char *PR_GlobalStringNoContents (int ofs)
 {
 	static char	line[512];
+	static const int lastchari = Q_COUNTOF(line) - 2;
 	int		i;
 	ddef_t		*def;
 
@@ -454,7 +460,11 @@ const char *PR_GlobalStringNoContents (int ofs)
 	i = strlen(line);
 	for ( ; i < 20; i++)
 		strcat (line, " ");
-	strcat (line, " ");
+
+	if (i < lastchari)
+		strcat (line, " ");
+	else
+		line[lastchari] = ' ';
 
 	return line;
 }
