@@ -26,8 +26,8 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef __QSTDINC_H
-#define __QSTDINC_H
+#ifndef QSTDINC_H
+#define QSTDINC_H
 
 #include <sys/types.h>
 #include <stddef.h>
@@ -126,23 +126,23 @@ COMPILE_TIME_ASSERT(enum, sizeof(THE_DUMMY_ENUM) == sizeof(int));
 
 typedef unsigned char		byte;
 
+/* some structures have qboolean members and the x86 asm code expect
+ * those members to be 4 bytes long.  i.e.: qboolean must be 32 bits.  */
+typedef int	qboolean;
 #undef true
 #undef false
-#if defined(__cplusplus)
-/* some structures have qboolean members and the x86 asm code expect
- * those members to be 4 bytes long. therefore, qboolean must be 32
- * bits and it can NOT be binary compatible with the 8 bit C++ bool.  */
-typedef int	qboolean;
-COMPILE_TIME_ASSERT(falsehood, (0 == false));
-COMPILE_TIME_ASSERT(truth, (1  == true));
+#if !defined(__cplusplus)
+#if defined __STDC_VERSION__ && (__STDC_VERSION__ >= 199901L)
+#include <stdbool.h>
 #else
-typedef enum {
+enum {
 	false = 0,
 	true  = 1
-} qboolean;
+};
+#endif
+#endif /* */
 COMPILE_TIME_ASSERT(falsehood, ((1 != 1) == false));
 COMPILE_TIME_ASSERT(truth, ((1 == 1) == true));
-#endif
 COMPILE_TIME_ASSERT(qboolean, sizeof(qboolean) == 4);
 
 /*==========================================================================*/
@@ -244,6 +244,4 @@ typedef ptrdiff_t	ssize_t;
 
 /*==========================================================================*/
 
-
-#endif	/* __QSTDINC_H */
-
+#endif	/* QSTDINC_H */
